/**
 * Gulp tasks for wrapping Browserify modules.
 */
const display = require("./util/display");
const gulp = require("gulp");
const path = require("path");
const browserify = require("browserify");
const source = require("vinyl-source-stream");
const buffer = require("vinyl-buffer");
const sourcemaps = require("gulp-sourcemaps");
const uc = require("./util/unite-config");
const clientPackages = require("./util/client-packages");
const gutil = require("gulp-util");
const uglify = require("gulp-uglify");

gulp.task("build-bundle-app", () => {
    const uniteConfig = uc.getUniteConfig();
    const buildConfiguration = uc.getBuildConfiguration();

    if (buildConfiguration.bundle) {
        display.info("Running", "Browserify for App");

        const bApp = browserify({
            "debug": buildConfiguration.sourcemaps,
            "entries": `./${path.join(uniteConfig.directories.dist, "entryPoint.js")}`
        });

        const keys = clientPackages.getKeys(uniteConfig);

        keys.forEach((key) => {
            bApp.exclude(key);
        });

        return bApp.bundle()
            .pipe(source("app-bundle.js"))
            .pipe(buffer())
            .pipe(buildConfiguration.minify ? uglify()
                .on("error", (err) => {
                    display.error(err.toString());
                }) : gutil.noop())
            .pipe(buildConfiguration.sourcemaps ? sourcemaps.init({"loadMaps": true}) : gutil.noop())
            .pipe(buildConfiguration.sourcemaps ? sourcemaps.mapSources((sourcePath) => sourcePath.replace(/dist\//, "./")) : gutil.noop())
            .pipe(buildConfiguration.sourcemaps ? sourcemaps.write({"includeContent": true}) : gutil.noop())
            .pipe(gulp.dest(uniteConfig.directories.dist));
    }
});

/* Generated by UniteJS */
