/**
 * Gulp tasks for unit testing TypeScript.
 */
const display = require("./util/display");
const uc = require("./util/unite-config");
const gulp = require("gulp");
const replace = require("gulp-replace");
const typescript = require("gulp-typescript");
const sourcemaps = require("gulp-sourcemaps");

gulp.task("unit-transpile", () => {
    display.info("Running", "TypeScript");

    const uniteConfig = uc.getUniteConfig();

    const regEx = new RegExp(uniteConfig.srcDistReplace, "g");

    const tsProject = typescript.createProject("tsconfig.json");
    let errorCount = 0;

    return gulp.src(`${uniteConfig.directories.unitTestSrc}**/*.spec.ts`)
        .pipe(sourcemaps.init())
        .pipe(tsProject())
        .on("error", () => {
            errorCount++;
        })
        .js
        .pipe(replace(regEx, uniteConfig.srcDistReplaceWith))
        .pipe(sourcemaps.write({"includeContent": true}))
        .pipe(gulp.dest(uniteConfig.directories.unitTestDist))
        .on("end", () => {
            if (errorCount > 0) {
                process.exit();
            }
        });
});

/* Generated by UniteJS */
