/**
 * Gulp tasks for unit testing TypeScript.
 */
const display = require("./util/display");
const uc = require("./util/unite-config");
const gulp = require("gulp");
const path = require("path");
const fs = require("fs");
const del = require("del");
const runSequence = require("run-sequence");
const moduleConfig = require("./util/module-config");
require("./unit-transpile");
require("./unit-runner");
require("./unit-lint");

gulp.task("unit-clean", (callback) => {
    const uniteConfig = uc.getUniteConfig();
    const toClean = [
        path.join(uniteConfig.directories.unitTestDist, "**/*.spec.js"),
        path.join(uniteConfig.directories.reports, "unit/**/*"),
        path.join(uniteConfig.directories.reports, "coverage/**/*"),
        path.join(uniteConfig.directories.reports, "coverage.json"),
        path.join(uniteConfig.directories.reports, "coverage-final.json")
    ];
    display.info("Cleaning", toClean);
    return del(toClean, callback);
});

gulp.task("unit-module-config", (cb) => {
    const uniteConfig = uc.getUniteConfig();
    const buildConfiguration = uc.getBuildConfiguration();

    const config = moduleConfig.create(uniteConfig, ["test", "both"], buildConfiguration.bundle);

    fs.writeFile(path.join(uniteConfig.directories.unitTest, "unit-module-config.js"), config, (err) => {
        if (err) {
            display.error(err);
            process.exit(1);
        } else {
            cb();
        }
    });    
});

gulp.task("unit", (cb) => {
    runSequence("unit-clean", "unit-lint", "unit-transpile", "unit-module-config", "unit-run-test", cb);
});

gulp.task("unit-ui", (cb) => {
    runSequence("unit-clean", "unit-lint", "unit-transpile", "unit-module-config", "unit-run-test-ui", cb);
});

/* Generated by UniteJS */
