/**
 * Gulp utils for unite configuration.
 */
const display = require("./display");
const minimist = require("minimist");
const uniteConfigJson = require("../../../unite.json");

function getUniteConfig () {
    return uniteConfigJson;
}

function getBuildConfiguration (showInfo) {
    const knownOptions = {
        "default": {"buildConfiguration": "dev"},
        "string": ["buildConfiguration"]
    };

    const options = minimist(process.argv.slice(2), knownOptions);

    let buildConfiguration = null;

    if (uniteConfigJson && uniteConfigJson.buildConfigurations && uniteConfigJson.buildConfigurations[options.buildConfiguration]) {
        buildConfiguration = uniteConfigJson.buildConfigurations[options.buildConfiguration];
        if (showInfo) {
            display.info("Build Configuration", options.buildConfiguration);
        }
    } else {
        display.error(`Unknown build configuration '${options.buildConfiguration}' in unite.json, aborting.`);
        process.exit(1);
    }

    buildConfiguration = buildConfiguration || {};
    if (buildConfiguration.bundle === undefined) {
        buildConfiguration.bundle = false;
    }
    if (buildConfiguration.sourcemaps === undefined) {
        buildConfiguration.sourcemaps = true;
    }
    if (buildConfiguration.minify === undefined) {
        buildConfiguration.minify = false;
    }
    if (buildConfiguration.variables === undefined) {
        buildConfiguration.variables = {};
    }
    buildConfiguration.variables.name = options.buildConfiguration;
    if (showInfo) {
        display.info("Sourcemaps", buildConfiguration.sourcemaps);
        display.info("Minify", buildConfiguration.minify);
        display.info("Bundle", buildConfiguration.bundle);
    }

    return buildConfiguration;
}

module.exports = {
    getBuildConfiguration,
    getUniteConfig
};

/* Generated by UniteJS */
